@@ -60,7 +60,7 @@ import ConfigParser
 import os, os.path
 import datetime
 import time
-import pygst
+#import pygst
 #import gst
 import alarm
 import gobject
@@ -171,6 +171,254 @@ if os.path.exists(defdir):
         config.set('eng', 'duration', 'Required sleep duration (hours)')        
 else:
     os.mkdir(defdir)
+    with open(defdir+'/sleeppy-0001.log', 'w') as f:
+        f.write("""# 2010-04-14 23:04:36
+  0.0036 477.000
+  0.0044 437.454
+  0.0047 145.115
+  0.0050 191.915
+  0.0053 126.466
+  0.0056 468.179
+  0.0058 144.553
+  0.0064 398.064
+  0.0072 381.072
+  0.0072 227.703
+  0.0075 389.077
+  0.0078 319.221
+  0.0081 816.285
+  0.0097 619.848
+  0.0117 266.352
+  0.0119 702.015
+  0.0122 263.296
+  0.0125 122.756
+  0.1103 110.604
+  0.1108 485.935
+  0.1111 189.630
+  0.1114 327.724
+  0.1117 190.806
+  0.1119 136.293
+  0.1122 222.404
+  0.1125 395.129
+  0.1142 117.478
+  0.1142 113.357
+  0.1150 100.339
+  0.1153 180.934
+  0.1228 245.912
+  0.1233 226.968
+  0.1481 139.675
+  0.1539 202.119
+  0.1544 105.050
+  0.1553 179.047
+  0.1561 319.761
+  0.1561 146.166
+  0.1567 109.979
+  0.1567 104.180
+  0.1569 125.877
+  0.1572 258.478
+  0.1578 135.685
+  0.1578 126.383
+  0.1581 409.679
+  0.1617 151.794
+  0.1617 122.863
+  0.1622 128.936
+  0.1644 113.949
+  0.1681 208.148
+  0.1681 133.204
+  0.2139 101.445
+  0.2142 206.882
+  0.2147 109.847
+  0.2147 363.736
+  0.2150 168.608
+  0.2153 118.567
+  0.2350 239.624
+  0.2353 111.103
+  0.2356 154.303
+  0.2358 118.504
+  0.2361 403.868
+  0.2364 554.143
+  0.2367 264.115
+  0.2378 108.070
+  0.2492 252.132
+  0.2494 123.821
+  0.2808 153.079
+  0.2822 204.350
+  0.2833 190.846
+  0.2994 238.063
+  0.2994 304.000
+  0.2997 216.643
+  0.3547 257.165
+  0.3553 131.229
+  0.3556 524.882
+  0.3558 189.801
+  0.3561 617.686
+  0.3564 499.531
+  0.3567 195.625
+  0.3572 220.668
+  0.3572 141.055
+  0.3575 153.888
+  0.3578 187.096
+  0.3581 103.926
+  0.3586 422.564
+  0.3586 176.073
+  1.3975 141.297
+  1.3983 105.663
+  1.3997 101.582
+  1.4000 184.671
+  1.4003 265.141
+  1.4014 164.196
+  1.6897 162.004
+  2.2986 109.606
+  2.7250 207.490
+  2.7253 108.910
+  2.7269 105.284
+  2.7275 112.255
+  2.7275 111.028
+  2.7278 222.023
+  2.7289 167.154
+  2.7289 273.436
+  2.7297 197.673
+  2.7317 115.853
+  2.7317 161.100
+  2.7319 408.176
+  3.3139 264.244
+  3.4225 143.187
+  3.4231 140.608
+  3.4233 378.161
+  3.4236 270.024
+  3.4239 432.009
+  3.4242 414.052
+  3.4244 576.612
+  3.4247 372.385
+  3.4250 402.070
+  3.4253 207.429
+  3.4256 539.099
+  3.4769 147.149
+  3.5094 447.788
+  3.5225 199.098
+  3.6678 234.009
+  3.6681 516.545
+  3.7981 119.863
+  3.7983 124.073
+  3.7986 102.917
+  4.3708 227.677
+  4.3708 161.026
+  4.3711 581.570
+  4.3714 472.430
+  4.6567 267.436
+  4.6569 158.687
+  4.6581 358.597
+  4.9317 187.530
+  4.9319 144.798
+  4.9911 119.660
+  4.9914 138.610
+  4.9919 129.333
+  5.0878 130.495
+  5.0881 115.482
+  5.0883 399.418
+  5.0886 150.488
+  5.4989 179.209
+  5.4994 439.709
+  5.4997 365.170
+  5.8442 332.959
+  6.2231 443.551
+  6.2497 380.463
+  6.2683 156.777
+  6.3931 175.355
+  6.3939 105.529
+  6.3942 101.131
+  6.3944 101.707
+  6.3947 106.582
+  6.3950 397.914
+  6.3953 1302.469
+  6.3956 1067.468
+  7.1125 118.404
+  7.4864 295.324
+  7.4978 102.650
+  7.4986 107.179
+  7.4986 155.057
+  7.4989 370.962
+  7.7369 284.962
+  7.7369 249.755
+  7.7375 132.127
+  7.8172 153.477
+  7.9356 121.858
+  7.9369 146.673
+  7.9372 827.187
+  7.9375 315.333
+  7.9378 263.045
+  7.9381 623.806
+  7.9383 364.351
+  7.9386 208.922
+  7.9389 1172.658
+  7.9392 409.733
+  7.9394 561.339
+  7.9397 395.542
+  7.9986 112.599
+  8.1503 123.452
+  8.1511 173.403
+  8.1514 431.316
+  8.1517 237.259
+  8.2122 170.749
+  8.2128 328.002
+  8.2128 132.886
+  8.2133 193.815
+  8.2136 456.281
+  8.2139 399.140
+  8.2939 167.370
+  8.2942 109.546
+  8.2944 141.935
+  8.2950 109.126
+  8.2950 789.141
+  8.3844 530.187
+  8.3847 294.117
+  8.3850 134.648
+  8.3853 144.186
+  8.3856 458.676
+  8.5161 364.420
+  8.5164 152.787
+  8.5178 200.644
+  8.5181 455.643
+  8.5183 346.956
+  9.0228 158.601
+  9.0231 405.579
+  9.1561 136.069
+  9.2781 517.708
+  9.2783 152.842
+  9.2794 121.035
+  9.2803 102.471
+  9.2806 183.141
+  9.2808 195.533
+  9.3631 104.296
+  9.3639 190.749
+  9.3642 129.331
+  9.4869 107.945
+  9.4875 226.479
+  9.4875 132.147
+  9.4878 845.868
+  9.4881 668.945
+  9.4883 176.560
+  9.4886 187.322
+  9.5761 216.211
+  9.5764 174.786
+  9.5767 117.623
+  9.7289 106.999
+  9.7292 134.097
+  9.7306 101.598
+  9.7311 127.112
+  9.7317 283.058
+  9.7319 170.815
+  9.7322 182.226
+  9.7325 483.905
+  9.7328 250.508
+  9.7331 167.153
+  9.7333 423.180
+  9.7336 416.933
+  9.7339 934.469
+  9.7344 444.880
+  9.9247 134.694
+  9.9261 117.198
+  9.9264 584.951
+ 10.5989 237.638 """)
 
 border = 2
     
